@@ -19,25 +19,26 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
   end
 
   def self.parse_subnet_id(value)
-    fixed_ips = JSON.parse(value.gsub(/\\"/,'"').gsub('\'','"'))
+    fixed_ips = parse_python_list(value)
     subnet_ids = []
     fixed_ips.each do |fixed_ip|
       subnet_ids << fixed_ip['subnet_id']
     end
-
-    if subnet_ids.length > 1
-      subnet_ids
-    else
-      subnet_ids.first
-    end
+    # TODO(tkajinam): Support multiple values
+    subnet_ids.first
   end
 
   def self.parse_availability_zone_hint(value)
-    hints = JSON.parse(value.gsub(/\\"/,'"').gsub('\'','"'))
-    if hints.length > 1
-      hints
+    hints = parse_python_list(value)
+    # TODO(tkajinam): Support multiple values
+    hints.first
+  end
+
+  def self.parse_boolean(value)
+    if value.nil?
+      nil
     else
-      hints.first
+      value.downcase.chomp == 'true' ? :true : :false
     end
   end
 end
