@@ -44,7 +44,7 @@ Puppet::Type.type(:neutron_subnet).provide(
         :allocation_pools  => parse_allocation_pool(subnet[:allocation_pools]),
         :host_routes       => parse_host_routes(subnet[:host_routes]),
         :dns_nameservers   => parse_dns_nameservers(subnet[:dns_nameservers]),
-        :enable_dhcp       => subnet[:enable_dhcp],
+        :enable_dhcp       => subnet[:enable_dhcp].downcase.chomp == 'true'? :true : :false,
         :network_id        => subnet[:network_id],
         :network_name      => get_network_name(subnet[:network_id]),
         :project_id        => subnet[:project_id],
@@ -70,12 +70,9 @@ Puppet::Type.type(:neutron_subnet).provide(
 
   def self.parse_allocation_pool(values)
     allocation_pools = []
-    return [] if values.empty? or values == '[]'
-    values = values.gsub('[', '').gsub(']', '')
-    for value in Array(values)
-      allocation_pool = JSON.parse(value.gsub(/\\"/,'"').gsub('\'','"'))
-      start_ip = allocation_pool['start']
-      end_ip = allocation_pool['end']
+    parse_python_list(values).each do |pool|
+      start_ip = pool['start']
+      end_ip = pool['end']
       allocation_pools << "start=#{start_ip},end=#{end_ip}"
     end
     return allocation_pools
@@ -83,24 +80,16 @@ Puppet::Type.type(:neutron_subnet).provide(
 
   def self.parse_host_routes(values)
     host_routes = []
-    return [] if values.empty? or values == '[]'
-    values = values.gsub('[', '').gsub(']', '')
-    for value in Array(values)
-      host_route = JSON.parse(value.gsub(/\\"/,'"').gsub('\'','"'))
-      nexthop = host_route['nexthop']
-      destination = host_route['destination']
+    parse_python_list(values).each do |route|
+      nexthop = route['nexthop']
+      destination = route['destination']
       host_routes << "destination=#{destination},nexthop=#{nexthop}"
     end
     return host_routes
   end
 
   def self.parse_dns_nameservers(values)
-    if values.is_a? String
-        values = values.gsub('\'','').gsub('[', '').gsub(']', '')
-                       .gsub(',', '').split(' ')
-    end
-    # just enforce that this is actually an array
-    return Array(values)
+    return parse_python_list(values)
   end
 
   def exists?
@@ -134,7 +123,7 @@ Puppet::Type.type(:neutron_subnet).provide(
       end
     end
 
-    if @resource[:enable_dhcp] == 'False'
+    if @resource[:enable_dhcp] == :false
       opts << "--no-dhcp"
     else
       opts << "--dhcp"
@@ -185,7 +174,7 @@ Puppet::Type.type(:neutron_subnet).provide(
       :allocation_pools  => self.class.parse_allocation_pool(subnet[:allocation_pools]),
       :host_routes       => self.class.parse_host_routes(subnet[:host_routes]),
       :dns_nameservers   => self.class.parse_dns_nameservers(subnet[:dns_nameservers]),
-      :enable_dhcp       => subnet[:enable_dhcp],
+      :enable_dhcp       => subnet[:enable_dhcp].downcase.chomp == 'true'? :true : :false,
       :network_id        => subnet[:network_id],
       :network_name      => self.class.get_network_name(subnet[:network_id]),
       :project_id        => subnet[:project_id],
@@ -206,7 +195,7 @@ Puppet::Type.type(:neutron_subnet).provide(
       end
 
       if @property_flush.has_key?(:enable_dhcp)
-        if @property_flush[:enable_dhcp] == 'False'
+        if @property_flush[:enable_dhcp] == :false
           opts << '--no-dhcp'
         else
           opts << '--dhcp'
