@@ -16,19 +16,19 @@ Puppet::Type.newtype(:neutron_network) do
 
   newproperty(:admin_state_up) do
     desc 'The administrative status of the network'
-    newvalues(/(t|T)rue/, /(f|F)alse/)
-    defaultto 'True'
+    newvalues(/(t|T)rue/, /(f|F)alse/, true, false)
+    defaultto(true)
     munge do |v|
-      v.to_s.capitalize
+      v.to_s.downcase.to_sym
     end
   end
 
   newproperty(:shared) do
     desc 'Whether this network should be shared across all tenants or not'
-    newvalues(/(t|T)rue/, /(f|F)alse/)
-    defaultto 'False'
+    newvalues(/(t|T)rue/, /(f|F)alse/, true, false)
+    defaultto(false)
     munge do |v|
-      v.to_s.capitalize
+      v.to_s.downcase.to_sym
     end
   end
 
@@ -62,10 +62,10 @@ Puppet::Type.newtype(:neutron_network) do
 
   newproperty(:router_external) do
     desc 'Whether this router will route traffic to an external network'
-    newvalues(/(t|T)rue/, /(f|F)alse/)
-    defaultto 'False'
+    newvalues(/(t|T)rue/, /(f|F)alse/, true, false)
+    defaultto(false)
     munge do |v|
-      v.to_s.capitalize
+      v.to_s.downcase.to_sym
     end
   end
 
