@@ -29,10 +29,6 @@ Puppet::Type.newtype(:neutron_security_group) do
 
   ensurable
 
-  autorequire(:neutron_config) do
-    ['auth_url', 'project_name', 'username', 'password']
-  end
-
   # Require the neutron-server service to be running
   autorequire(:anchor) do
     ['neutron::service::end']
