@@ -8,14 +8,15 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/l3_agent.ini',
                      '/etc/neutron/metadata_agent.ini',
                      '/etc/neutron/metering_agent.ini',
-                     '/etc/neutron/l2gw_plugin.ini',
+                     '/etc/neutron/networking_l2gw.conf',
                      '/etc/neutron/l2gateway_agent.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf.ini',
+                     '/etc/neutron/fwaas_driver.ini',
+                     '/etc/neutron/neutron_fwaas.conf',
                      '/etc/neutron/vpn_agent.ini',
                      '/etc/neutron/neutron_vpnaas.conf',
                      '/etc/neutron/ovn_vpn_agent.ini',
                      '/etc/neutron/taas_plugin.ini',
-                     '/etc/neutron/plugins/ml2/linuxbridge_agent.ini',
                      '/etc/neutron/plugins/ml2/openvswitch_agent.ini',
                      '/etc/neutron/plugins/ml2/ovn_agent.ini',
                      '/etc/neutron/plugins/ml2/sriov_agent.ini',
@@ -32,11 +33,12 @@ describe 'basic neutron_config resource' do
   File <||> -> Neutron_metering_agent_config <||>
   File <||> -> Neutron_plugin_ml2 <||>
   File <||> -> Neutron_l2gw_service_config <||>
+  File <||> -> Neutron_fwaas_agent_config <||>
+  File <||> -> Neutron_fwaas_service_config <||>
   File <||> -> Neutron_vpnaas_agent_config <||>
   File <||> -> Neutron_vpnaas_service_config <||>
   File <||> -> Neutron_ovn_vpn_agent_config <||>
   File <||> -> Neutron_taas_service_config <||>
-  File <||> -> Neutron_agent_linuxbridge <||>
   File <||> -> Neutron_agent_ovs <||>
   File <||> -> Neutron_agent_ovn <||>
   File <||> -> Neutron_sriov_agent_config <||>
@@ -54,14 +56,15 @@ describe 'basic neutron_config resource' do
                      '/etc/neutron/l3_agent.ini',
                      '/etc/neutron/metadata_agent.ini',
                      '/etc/neutron/metering_agent.ini',
-                     '/etc/neutron/l2gw_plugin.ini',
+                     '/etc/neutron/networking_l2gw.conf',
                      '/etc/neutron/l2gateway_agent.ini',
                      '/etc/neutron/plugins/ml2/ml2_conf.ini',
+                     '/etc/neutron/fwaas_driver.ini',
+                     '/etc/neutron/neutron_fwaas.conf',
                      '/etc/neutron/vpn_agent.ini',
                      '/etc/neutron/neutron_vpnaas.conf',
                      '/etc/neutron/ovn_vpn_agent.ini',
                      '/etc/neutron/taas_plugin.ini',
-                     '/etc/neutron/plugins/ml2/linuxbridge_agent.ini',
                      '/etc/neutron/plugins/ml2/openvswitch_agent.ini',
                      '/etc/neutron/plugins/ml2/ovn_agent.ini',
                      '/etc/neutron/plugins/ml2/sriov_agent.ini',
@@ -201,6 +204,42 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
+  neutron_fwaas_agent_config { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_fwaas_agent_config { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_fwaas_agent_config { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_fwaas_agent_config { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_fwaas_service_config { 'DEFAULT/thisshouldexist' :
+    value => 'foo',
+  }
+
+  neutron_fwaas_service_config { 'DEFAULT/thisshouldnotexist' :
+    value => '<SERVICE DEFAULT>',
+  }
+
+  neutron_fwaas_service_config { 'DEFAULT/thisshouldexist2' :
+    value             => '<SERVICE DEFAULT>',
+    ensure_absent_val => 'toto',
+  }
+
+  neutron_fwaas_service_config { 'DEFAULT/thisshouldnotexist2' :
+    value             => 'toto',
+    ensure_absent_val => 'toto',
+  }
+
   neutron_vpnaas_agent_config { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -273,24 +312,6 @@ describe 'basic neutron_config resource' do
     ensure_absent_val => 'toto',
   }
 
-  neutron_agent_linuxbridge { 'DEFAULT/thisshouldexist' :
-    value => 'foo',
-  }
-
-  neutron_agent_linuxbridge { 'DEFAULT/thisshouldnotexist' :
-    value => '<SERVICE DEFAULT>',
-  }
-
-  neutron_agent_linuxbridge { 'DEFAULT/thisshouldexist2' :
-    value             => '<SERVICE DEFAULT>',
-    ensure_absent_val => 'toto',
-  }
-
-  neutron_agent_linuxbridge { 'DEFAULT/thisshouldnotexist2' :
-    value             => 'toto',
-    ensure_absent_val => 'toto',
-  }
-
   neutron_agent_ovs { 'DEFAULT/thisshouldexist' :
     value => 'foo',
   }
@@ -408,11 +429,12 @@ describe 'basic neutron_config resource' do
                     'neutron_metadata_agent_config',
                     'neutron_metering_agent_config',
                     'neutron_plugin_ml2',
+                    'neutron_fwaas_agent_config',
+                    'neutron_fwaas_service_config',
                     'neutron_vpnaas_agent_config',
                     'neutron_vpnaas_service_config',
                     'neutron_ovn_vpn_agent_config',
                     'neutron_taas_service_config',
-                    'neutron_agent_linuxbridge',
                     'neutron_agent_ovs',
                     'neutron_agent_ovn',
                     'neutron_sriov_agent_config',
