@@ -37,7 +37,7 @@ describe 'neutron::agents::ml2::ovn' do
 
     it 'configures ovn_agent.ini' do
       should contain_neutron_agent_ovn('DEFAULT/debug').with(:value => '<SERVICE DEFAULT>')
-      should contain_neutron_agent_ovn('DEFAULT/state_path').with(:value => '/var/lib/neutron')
+      should contain_neutron_agent_ovn('DEFAULT/state_path').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('agent/extensions').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('agent/root_helper').with(:value => 'sudo neutron-rootwrap /etc/neutron/rootwrap.conf')
       should contain_neutron_agent_ovn('agent/root_helper_daemon').with(:value => '<SERVICE DEFAULT>')
@@ -45,7 +45,13 @@ describe 'neutron::agents::ml2::ovn' do
       should contain_neutron_agent_ovn('ovs/ovsdb_connection_timeout').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('ovn/ovsdb_connection_timeout').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('ovn/ovn_nb_connection').with(:value => '<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovn('ovn/ovn_nb_private_key').with(:value => '<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovn('ovn/ovn_nb_certificate').with(:value => '<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovn('ovn/ovn_nb_ca_cert').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('ovn/ovn_sb_connection').with(:value => '<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovn('ovn/ovn_sb_private_key').with(:value => '<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovn('ovn/ovn_sb_certificate').with(:value => '<SERVICE DEFAULT>')
+      should contain_neutron_agent_ovn('ovn/ovn_sb_ca_cert').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('ovn/ovsdb_retry_max_interval').with(:value => '<SERVICE DEFAULT>')
       should contain_neutron_agent_ovn('ovn/ovsdb_probe_interval').with(:value => '<SERVICE DEFAULT>')
     end
@@ -73,7 +79,7 @@ describe 'neutron::agents::ml2::ovn' do
       end
 
       let (:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :neutron_ovn_agent_package => 'neutron-ovn-agent',
             :neutron_ovn_agent_service => 'neutron-ovn-agent' }
