@@ -74,12 +74,13 @@ describe 'neutron::config' do
       { :ovs_agent_config         => config_hash,
         :ovn_agent_config         => config_hash,
         :sriov_agent_config       => config_hash,
-        :linuxbridge_agent_config => config_hash,
         :macvtap_agent_config     => config_hash,
         :l3_agent_config          => config_hash,
         :dhcp_agent_config        => config_hash,
         :metadata_agent_config    => config_hash,
         :metering_agent_config    => config_hash,
+        :fwaas_agent_config       => config_hash,
+        :fwaas_service_config     => config_hash,
         :vpnaas_agent_config      => config_hash,
         :vpnaas_service_config    => config_hash,
         :ovn_vpn_agent_config     => config_hash,
@@ -107,12 +108,6 @@ describe 'neutron::config' do
       should contain_neutron_sriov_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
-    it 'configures arbitrary neutron_agent_linuxbridge configurations' do
-      should contain_neutron_agent_linuxbridge('DEFAULT/foo').with_value('fooValue')
-      should contain_neutron_agent_linuxbridge('DEFAULT/bar').with_value('barValue')
-      should contain_neutron_agent_linuxbridge('DEFAULT/baz').with_ensure('absent')
-    end
-
     it 'configures arbitrary neutron_agent_macvtap configurations' do
       should contain_neutron_agent_macvtap('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_agent_macvtap('DEFAULT/bar').with_value('barValue')
@@ -143,6 +138,18 @@ describe 'neutron::config' do
       should contain_neutron_metering_agent_config('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary fwaas_agent_config configurations' do
+      should contain_neutron_fwaas_agent_config('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_fwaas_agent_config('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_fwaas_agent_config('DEFAULT/baz').with_ensure('absent')
+    end
+
+    it 'configures arbitrary fwaas_service_config configurations' do
+      should contain_neutron_fwaas_service_config('DEFAULT/foo').with_value('fooValue')
+      should contain_neutron_fwaas_service_config('DEFAULT/bar').with_value('barValue')
+      should contain_neutron_fwaas_service_config('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary vpnaas_agent_config configurations' do
       should contain_neutron_vpnaas_agent_config('DEFAULT/foo').with_value('fooValue')
       should contain_neutron_vpnaas_agent_config('DEFAULT/bar').with_value('barValue')
