@@ -23,6 +23,7 @@ describe 'neutron' do
     it_behaves_like 'with SSL socket options set'
     it_behaves_like 'with SSL socket options set with wrong parameters'
     it_behaves_like 'with SSL socket options left by default'
+    it_behaves_like 'with SSL socket options set and no ca_file'
     it_behaves_like 'without service_plugins'
     it_behaves_like 'with service_plugins'
     it_behaves_like 'with host defined'
@@ -30,8 +31,7 @@ describe 'neutron' do
     it_behaves_like 'with transport_url defined'
     it_behaves_like 'with rootwrap daemon'
     it_behaves_like 'with max_allowed_address_pair defined'
-    it_behaves_like 'when disabling vlan_transparent'
-    it_behaves_like 'when enabling vlan_transparent'
+    it_behaves_like 'when vlan transparent options defined'
   end
 
   shared_examples 'a neutron base installation' do
@@ -64,7 +64,6 @@ describe 'neutron' do
       should contain_oslo__messaging__rabbit('neutron_config').with(
         :heartbeat_timeout_threshold          => '<SERVICE DEFAULT>',
         :heartbeat_rate                       => '<SERVICE DEFAULT>',
-        :heartbeat_in_pthread                 => '<SERVICE DEFAULT>',
         :rabbit_qos_prefetch_count            => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                       => '<SERVICE DEFAULT>',
         :rabbit_transient_queues_ttl          => '<SERVICE DEFAULT>',
@@ -73,12 +72,15 @@ describe 'neutron' do
         :kombu_failover_strategy              => '<SERVICE DEFAULT>',
         :kombu_compression                    => '<SERVICE DEFAULT>',
         :amqp_durable_queues                  => '<SERVICE DEFAULT>',
+        :amqp_auto_delete                     => '<SERVICE DEFAULT>',
         :rabbit_ha_queues                     => '<SERVICE DEFAULT>',
         :rabbit_quorum_queue                  => '<SERVICE DEFAULT>',
         :rabbit_transient_quorum_queue        => '<SERVICE DEFAULT>',
         :rabbit_quorum_delivery_limit         => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length      => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes       => '<SERVICE DEFAULT>',
+        :use_queue_manager                    => '<SERVICE DEFAULT>',
+        :rabbit_stream_fanout                 => '<SERVICE DEFAULT>',
         :enable_cancel_on_failover            => '<SERVICE DEFAULT>',
       )
     end
@@ -110,6 +112,7 @@ describe 'neutron' do
       )
 
       should contain_neutron_config('DEFAULT/vlan_transparent').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('DEFAULT/vlan_qinq').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('agent/root_helper').with_value('sudo neutron-rootwrap /etc/neutron/rootwrap.conf')
       should contain_neutron_config('agent/root_helper_daemon').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('agent/report_interval').with_value('<SERVICE DEFAULT>')
@@ -121,7 +124,6 @@ describe 'neutron' do
       params.merge!(
         :rabbit_heartbeat_timeout_threshold => 60,
         :rabbit_heartbeat_rate              => 10,
-        :rabbit_heartbeat_in_pthread        => true,
         :amqp_durable_queues                => true,
         :rabbit_ha_queues                   => true,
         :rabbit_transient_queues_ttl        => 20,
@@ -132,7 +134,6 @@ describe 'neutron' do
       should contain_oslo__messaging__rabbit('neutron_config').with(
         :heartbeat_timeout_threshold => 60,
         :heartbeat_rate              => 10,
-        :heartbeat_in_pthread        => true,
         :amqp_durable_queues         => true,
         :rabbit_ha_queues            => true,
         :rabbit_transient_queues_ttl => 20,
@@ -171,9 +172,11 @@ describe 'neutron' do
     end
 
     it { should contain_neutron_config('DEFAULT/use_ssl').with_value('true') }
-    it { should contain_neutron_config('ssl/cert_file').with_value('/path/to/cert') }
-    it { should contain_neutron_config('ssl/key_file').with_value('/path/to/key') }
-    it { should contain_neutron_config('ssl/ca_file').with_value('/path/to/ca') }
+    it { should contain_oslo__service__ssl('neutron_config').with(
+      :cert_file => '/path/to/cert',
+      :key_file  => '/path/to/key',
+      :ca_file   => '/path/to/ca'
+    ) }
   end
 
   shared_examples 'with SSL socket options set with wrong parameters' do
@@ -191,9 +194,11 @@ describe 'neutron' do
   shared_examples 'with SSL socket options left by default' do
 
     it { should contain_neutron_config('DEFAULT/use_ssl').with_value('<SERVICE DEFAULT>') }
-    it { should contain_neutron_config('ssl/cert_file').with_value('<SERVICE DEFAULT>') }
-    it { should contain_neutron_config('ssl/key_file').with_value('<SERVICE DEFAULT>') }
-    it { should contain_neutron_config('ssl/ca_file').with_value('<SERVICE DEFAULT>') }
+    it { should contain_oslo__service__ssl('neutron_config').with(
+      :cert_file => '<SERVICE DEFAULT>',
+      :key_file  => '<SERVICE DEFAULT>',
+      :ca_file   => '<SERVICE DEFAULT>'
+    ) }
   end
 
   shared_examples 'with SSL socket options set and no ca_file' do
@@ -206,20 +211,11 @@ describe 'neutron' do
     end
 
     it { should contain_neutron_config('DEFAULT/use_ssl').with_value('true') }
-    it { should contain_neutron_config('ssl/cert_file').with_value('/path/to/cert') }
-    it { should contain_neutron_config('ssl/key_file').with_value('/path/to/key') }
-    it { should contain_neutron_config('ssl/ca_file').with_ensure('absent') }
-  end
-
-  shared_examples 'with SSL socket options disabled with ca_file' do
-    before do
-      params.merge!(
-        :use_ssl => false,
-        :ca_file => '/path/to/ca'
-      )
-    end
-
-    it { should raise_error(Puppet::Error, /The ca_file parameter requires that use_ssl to be set to true/) }
+    it { should contain_oslo__service__ssl('neutron_config').with(
+      :cert_file => '/path/to/cert',
+      :key_file  => '/path/to/key',
+      :ca_file   => '<SERVICE DEFAULT>'
+    ) }
   end
 
   shared_examples 'with non-default kombu options' do
@@ -305,25 +301,16 @@ describe 'neutron' do
     }
   end
 
-  shared_examples 'when disabling vlan_transparent' do
+  shared_examples 'when vlan transparent options defined' do
     before do
       params.merge!(
-        :vlan_transparent => false
-      )
-    end
-    it do
-      should contain_neutron_config('DEFAULT/vlan_transparent').with_value(false)
-    end
-  end
-
-  shared_examples 'when enabling vlan_transparent' do
-    before do
-      params.merge!(
-        :vlan_transparent => true
+        :vlan_transparent => true,
+        :vlan_qinq        => false,
       )
     end
     it do
       should contain_neutron_config('DEFAULT/vlan_transparent').with_value(true)
+      should contain_neutron_config('DEFAULT/vlan_qinq').with_value(false)
     end
   end
 
