@@ -5,76 +5,62 @@ describe 'neutron::server' do
     "class { 'neutron': }
      class { 'neutron::keystone::authtoken':
        password => 'passw0rd',
-     }"
+     }
+     include apache"
   end
 
   let :params do
-    {}
-  end
-
-  let :default_params do
-    {
-      :package_ensure           => 'present',
-      :enabled                  => true,
-      :auth_strategy            => 'keystone',
-      :sync_db                  => false,
-    }
+    { :api_service_name => 'httpd' }
   end
 
   shared_examples 'neutron::server' do
-    let :p do
-      default_params.merge(params)
-    end
-
     it { should contain_class('neutron::db') }
     it { should contain_class('neutron::params') }
     it { should contain_class('neutron::policy') }
 
-    it 'installs neutron server package' do
-      if platform_params.has_key?(:server_package)
-        should contain_package('neutron-server').with(
-          :name   => platform_params[:server_package],
-          :ensure => p[:package_ensure],
+    it 'installs neutron server service' do
+      if platform_params.has_key?(:api_package_name)
+        should contain_package('neutron-api').with(
+          :name   => platform_params[:api_package_name],
+          :ensure => 'present',
           :tag    => ['openstack', 'neutron-package'],
         )
-        should contain_package('neutron-server').that_requires('Anchor[neutron::install::begin]')
-        should contain_package('neutron-server').that_notifies('Anchor[neutron::install::end]')
-      else
-        should contain_package('neutron').that_requires('Anchor[neutron::install::begin]')
-        should contain_package('neutron').that_notifies('Anchor[neutron::install::end]')
       end
+      if platform_params.has_key?(:api_service_name)
+        should contain_service('neutron-api').with(
+          :ensure   => 'stopped',
+          :name     => platform_params[:api_service_name],
+          :enable   => false,
+          :tag      => ['neutron-service'],
+        )
+      end
+
+      should contain_package('neutron-rpc-server').with(
+        :name   => platform_params[:rpc_package_name],
+        :ensure => 'present',
+        :tag    => ['openstack', 'neutron-package'],
+      )
+      should contain_service('neutron-rpc-server').with(
+        :name    => platform_params[:rpc_service_name],
+        :enable  => true,
+        :ensure  => 'running',
+        :tag     => ['neutron-service'],
+      )
+
+      should contain_package('neutron-periodic-workers').with(
+        :name   => platform_params[:periodic_workers_package_name],
+        :ensure => 'present',
+        :tag    => ['openstack', 'neutron-package'],
+      )
+      should contain_service('neutron-periodic-workers').with(
+        :ensure => 'running',
+        :name   => platform_params[:periodic_workers_service_name],
+        :enable => true,
+        :tag    => ['neutron-service'],
+      )
     end
 
     it 'configures neutron server service' do
-      if platform_params.has_key?(:server_service)
-        should contain_service('neutron-server').with(
-          :name    => platform_params[:server_service],
-          :enable  => true,
-          :ensure  => 'running',
-          :tag     => ['neutron-service', 'neutron-server-eventlet'],
-        )
-        should contain_service('neutron-server').that_subscribes_to('Anchor[neutron::service::begin]')
-        should contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
-      else
-        should contain_service('neutron-api').with(
-          :name    => platform_params[:api_service_name],
-          :enable  => true,
-          :ensure  => 'running',
-          :tag     => ['neutron-service', 'neutron-server-eventlet'],
-        )
-        should contain_service('neutron-api').that_subscribes_to('Anchor[neutron::service::begin]')
-        should contain_service('neutron-api').that_notifies('Anchor[neutron::service::end]')
-
-        should contain_service('neutron-rpc-server').with(
-          :name    => platform_params[:rpc_service_name],
-          :enable  => true,
-          :ensure  => 'running',
-          :tag     => ['neutron-service'],
-        )
-        should contain_service('neutron-rpc-server').that_subscribes_to('Anchor[neutron::service::begin]')
-        should contain_service('neutron-rpc-server').that_notifies('Anchor[neutron::service::end]')
-      end
-
       should_not contain_class('neutron::db::sync')
       should contain_neutron_config('DEFAULT/api_workers').with_value(facts[:os_workers])
       should contain_neutron_config('DEFAULT/rpc_workers').with_value(facts[:os_workers])
@@ -88,6 +74,7 @@ describe 'neutron::server' do
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
         :max_request_body_size        => '<SERVICE DEFAULT>',
       )
+      should contain_neutron_config('DEFAULT/pagination_max_limit').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('ovs/integration_bridge').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('ovs/igmp_snooping_enable').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('ovs/igmp_flood').with_value('<SERVICE DEFAULT>')
@@ -103,12 +90,9 @@ describe 'neutron::server' do
       end
 
       it 'should not manage the service' do
-        if platform_params.has_key?(:server_service)
-          should_not contain_service('neutron-server')
-        else
-          should_not contain_service('neutron-api')
-          should_not contain_service('neutron-rpc-server')
-        end
+        should_not contain_service('neutron-api')
+        should_not contain_service('neutron-rpc-server')
+        should_not contain_service('neutron-periodic-workers')
       end
     end
 
@@ -268,87 +252,6 @@ describe 'neutron::server' do
       )}
     end
 
-    context 'when running neutron-api in wsgi' do
-      before :each do
-        params.merge!(
-          :service_name     => false,
-          :api_service_name => 'httpd',
-        )
-      end
-
-      let :pre_condition do
-        "class { 'neutron': }
-         include apache
-         class { 'neutron::keystone::authtoken':
-           password => 'passw0rd',
-         }"
-      end
-
-      it 'configures neutron-api service with Apache' do
-        if platform_params.has_key?(:server_service)
-          should contain_service('neutron-server').with(
-            :ensure     => 'stopped',
-            :name       => platform_params[:server_service],
-            :enable     => false,
-            :tag        => ['neutron-service'],
-          )
-        else
-          should contain_service('neutron-api').with(
-            :ensure     => 'stopped',
-            :name       => platform_params[:api_service_name],
-            :enable     => false,
-            :tag        => ['neutron-service'],
-          )
-        end
-
-        if platform_params.has_key?(:rpc_package_name)
-          should contain_package('neutron-rpc-server').with(
-            :name   => platform_params[:rpc_package_name],
-            :ensure => 'present',
-            :tag    => ['openstack', 'neutron-package'],
-          )
-        end
-        if platform_params.has_key?(:rpc_service_name)
-          should contain_service('neutron-rpc-server').with(
-            :ensure => 'running',
-            :name   => platform_params[:rpc_service_name],
-            :enable => true,
-            :tag    => ['neutron-service'],
-          )
-        end
-        if platform_params.has_key?(:periodic_workers_package_name)
-          should contain_package('neutron-periodic-workers').with(
-            :name   => platform_params[:periodic_workers_package_name],
-            :ensure => 'present',
-            :tag    => ['openstack', 'neutron-package'],
-          )
-        end
-        if platform_params.has_key?(:periodic_workers_service_name)
-          should contain_service('neutron-periodic-workers').with(
-            :ensure => 'running',
-            :name   => platform_params[:periodic_workers_service_name],
-            :enable => true,
-            :tag    => ['neutron-service'],
-          )
-        end
-      end
-    end
-
-    context 'when service_name is customized' do
-      before :each do
-        params.merge!({ :service_name => 'foobar' })
-      end
-
-      it 'configures neutron-api service with custom name' do
-        should contain_service('neutron-server').with(
-          :name    => 'foobar',
-          :enable  => true,
-          :ensure  => 'running',
-          :tag     => ['neutron-service'],
-        )
-      end
-    end
-
     context 'with ovs_integration_bridge set' do
       before :each do
         params.merge!({:ovs_integration_bridge => 'br-int' })
@@ -397,20 +300,6 @@ describe 'neutron::server' do
       end
     end
 
-    context 'with Dynamic routing package installation' do
-      before do
-        params.merge!( :ensure_dr_package => true )
-      end
-
-      it 'should install dynamic routing package' do
-        should contain_package('neutron-dynamic-routing').with(
-          :ensure => 'installed',
-          :name   => platform_params[:dynamic_routing_package],
-          :tag    => ['openstack', 'neutron-package'],
-        )
-      end
-    end
-
     context 'without database synchronization' do
       before do
         params.merge!(
@@ -424,6 +313,33 @@ describe 'neutron::server' do
     end
   end
 
+  shared_examples 'neutron::server in Debian' do
+    before :each do
+      params.clear()
+    end
+
+    let :pre_condition do
+      "class { 'neutron': }
+       class { 'neutron::keystone::authtoken':
+         password => 'passw0rd',
+       }"
+    end
+
+    it 'installs neutron server service' do
+      should contain_package('neutron-api').with(
+        :name   => platform_params[:api_package_name],
+        :ensure => 'present',
+        :tag    => ['openstack', 'neutron-package'],
+      )
+      should contain_service('neutron-api').with(
+        :ensure   => 'running',
+        :name     => platform_params[:api_service_name],
+        :enable   => true,
+        :tag      => ['neutron-service'],
+      )
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -437,34 +353,36 @@ describe 'neutron::server' do
         when 'Debian'
           if facts[:os]['name'] == 'Ubuntu'
             {
-              :server_package          => 'neutron-server',
-              :server_service          => 'neutron-server',
-              :dynamic_routing_package => 'python3-neutron-dynamic-routing',
-              :vpnaas_agent_package    => 'python3-neutron-vpnaas',
+              :api_package_name              => 'neutron-api',
+              :rpc_package_name              => 'neutron-rpc-server',
+              :rpc_service_name              => 'neutron-rpc-server',
+              :periodic_workers_package_name => 'neutron-periodic-workers',
+              :periodic_workers_service_name => 'neutron-periodic-workers',
             }
           else
             {
-              :api_service_name        => 'neutron-api',
-              :rpc_package_name        => 'neutron-rpc-server',
-              :rpc_service_name        => 'neutron-rpc-server',
-              :dynamic_routing_package => 'python3-neutron-dynamic-routing',
-              :vpnaas_agent_package    => 'python3-neutron-vpnaas',
+              :api_package_name              => 'neutron-api',
+              :api_service_name              => 'neutron-api',
+              :rpc_package_name              => 'neutron-rpc-server',
+              :rpc_service_name              => 'neutron-rpc-server',
+              :periodic_workers_package_name => 'neutron-periodic-workers',
+              :periodic_workers_service_name => 'neutron-periodic-workers',
             }
           end
         when 'RedHat'
           {
-            :server_service                => 'neutron-server',
             :rpc_package_name              => 'openstack-neutron-rpc-server',
             :rpc_service_name              => 'neutron-rpc-server',
             :periodic_workers_package_name => 'openstack-neutron-periodic-workers',
             :periodic_workers_service_name => 'neutron-periodic-workers',
-            :dynamic_routing_package       => 'python3-neutron-dynamic-routing',
-            :vpnaas_agent_package          => 'openstack-neutron-vpnaas',
           }
         end
       end
 
       it_behaves_like 'neutron::server'
+      if facts[:os]['name'] == 'Debian'
+        it_behaves_like 'neutron::server in Debian'
+      end
     end
   end
 end
