@@ -14,7 +14,7 @@ describe provider_class do
     provider = provider_class.new(resource)
     expect(provider.section).to eq('DEFAULT')
     expect(provider.setting).to eq('foo')
-    expect(provider.file_path).to eq('/etc/neutron/l2gw_plugin.ini')
+    expect(provider.file_path).to eq('/etc/neutron/networking_l2gw.conf')
   end
 
   it 'should allow setting to be set explicitly' do
@@ -27,7 +27,7 @@ describe provider_class do
     provider = provider_class.new(resource)
     expect(provider.section).to eq('dude')
     expect(provider.setting).to eq('foo')
-    expect(provider.file_path).to eq('/etc/neutron/l2gw_plugin.ini')
+    expect(provider.file_path).to eq('/etc/neutron/networking_l2gw.conf')
   end
 
   it 'should ensure absent when <SERVICE DEFAULT> is specified as a value' do
