@@ -9,12 +9,12 @@ describe 'Puppet::Type.type(:neutron_agent_ovs)' do
 
   it 'should autorequire the package that install the file' do
     catalog = Puppet::Resource::Catalog.new
-    package = Puppet::Type.type(:package).new(:name => 'neutron-ovs-agent')
-    catalog.add_resource package, @neutron_agent_ovs
+    anchor = Puppet::Type.type(:anchor).new(:name => 'neutron::install::end')
+    catalog.add_resource anchor, @neutron_agent_ovs
     dependency = @neutron_agent_ovs.autorequire
     expect(dependency.size).to eq(1)
     expect(dependency[0].target).to eq(@neutron_agent_ovs)
-    expect(dependency[0].source).to eq(package)
+    expect(dependency[0].source).to eq(anchor)
   end
 
 end
